%% Load data and control settings
clear all;
close all;

run_nr = 79;
calibration = 1; % 1 to use calibration for stb1, 2 for stb2;
flagSaveFigures = 0;

load('xPPT.mat');
load('zPPT_abs.mat');
load('zPPT_rel.mat');
load(strcat('calCoeffs',num2str(calibration),'.mat')); %Coefficients from the calibration
% load(strcat('AWG',num2str(run_nr),'Smooth.mat')); %Smoothed awg signals per section
load(strcat('StB_run',num2str(run_nr),'.mat'));
if run_nr > 9
    load(strcat('EC1StB_0',num2str(run_nr-14),'PPT.mat'));
elseif run_nr < 10
    load(strcat('StB2ppt_00',num2str(run_nr),'.mat'));
end
%Note that the ppt variable gives results from ppts used as wave-gauges.
load('prof_data_corrected');
profile_z = p(run_nr - 18).z;
profile_x = p(run_nr -18).x;
disp(head{run_nr - 18});

probeDistToBed = getProbeDistanceToBedWithScour(run_nr,xPPT,zPPT_abs,p);

rho = 1000;
g = 9.81;

[ppt_t,ppt_p] = getPPTData_1(PPT_data);
P = getPressureFromSignal(ppt_p,A,B);

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

%% Pressure gradients
% The pressure gradients are based on the mean pressure in an interval

interval  = [1000 1800];
[~,int_a] = min(abs(ppt_t - interval(1)));
[~,int_b] = min(abs(ppt_t - interval(2)));
intervalIdx = [int_a, int_b];
interval_t = ppt_t(int_a:int_b);

P_mean = mean(P(int_a:int_b,:),1);
P_fluct = P(int_a:int_b,:) - P_mean;

P_grad_abs = [(P_fluct(:,2) - P_fluct(:,1)),...
    (P_fluct(:,4) - P_fluct(:,2)),...
    (nan(size(P_fluct(:,3)))),...
    ...
    (P_fluct(:,6) - P_fluct(:,5)),...
    (P_fluct(:,7) - P_fluct(:,6)),...
    (P_fluct(:,8) - P_fluct(:,7)),...
    ...
    (P_fluct(:,10) - P_fluct(:,9)),...
    (nan(size(P_fluct(:,11)))),...
    (nan(size(P_fluct(:,12))))];

dzPPT = [zPPT_abs(2)-zPPT_abs(1),...
    zPPT_abs(4)-zPPT_abs(2),...
    nan,...
    zPPT_abs(6)-zPPT_abs(5),...
    zPPT_abs(7)-zPPT_abs(6),...
    zPPT_abs(8)-zPPT_abs(7),...
    zPPT_abs(10)-zPPT_abs(9),...
    nan,...
    nan];

P_grad = P_grad_abs./dzPPT;

legendTxt = ["0.303 - 0.203";...
    "0.203 - 0.173";...
    "";...
    "0.457 - 0.347";...
    "0.347 - 0.297";...
    "0.297 - 0.212";...
    "0.528 - 0.411";...
    "";...
    ""];

legendTxt = ["0.303 - 0.203";...
    "0.203 - 0.173";...
    "";...
    "0.457 - 0.347";...
    "0.347 - 0.297";...
    "0.297 - 0.212";...
    "0.528 - 0.411";...
    "";...
    ""];

%% AWG data

awg_idx = [20,19,14];

Fs = 40; % Hz, frequency of RWG, AWG and PPT
% Cut-off frequency for AWG (instrumentation noise)
Fc_hf = 8; %(highfreq) freq of short waves higher frequency limit
[B,A] = butter(4,Fc_hf/(Fs/2));

awg1 = AWG(:,awg_idx(1));
awg2 = AWG(:,awg_idx(2));
awg3 = AWG(:,awg_idx(3));
awg1_s = filtfilt(B,A,awg1);
awg2_s = filtfilt(B,A,awg2);
awg3_s = filtfilt(B,A,awg3);

%% Plot pressure and pressure gradients under waves
plot_int = [1003,1043];

init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
sg = rho*g;

%section 1
figure
ax1 = subplot(3,1,1);
plot(time_wp-time_wp(1),awg1_s - init_eta(1));
ylabel('$\eta$ [m]');

ax2 = subplot(3,1,2);
plot(interval_t,P_fluct(:,[1,2,4]));
legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4))));
ylabel('$\tilde{p}$ [Pa]');

ax3 = subplot(3,1,3);
plot(interval_t, P_grad(:,1:3)/sg);
legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$');
ylabel('$\nabla \tilde{p}$ [Pa/m]');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
figure
ax1 = subplot(3,1,1);
plot(time_wp-time_wp(1),awg2_s - init_eta(2));
ylabel('$\eta$ [m]');

ax2 = subplot(3,1,2);
plot(interval_t,P_fluct(:,[5:8]));
legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7))),strcat('$\Delta z_b = $',num2str(probeDistToBed(8))));
ylabel('$\tilde{p}$ [Pa]');

ax3 = subplot(3,1,3);
plot(interval_t, P_grad(:,4:6)/sg);
legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$', '$\nabla \tilde{p}_{3,4}$');
ylabel('$\nabla \tilde{p}$ [Pa/m]');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
figure
ax1 = subplot(3,1,1);
plot(time_wp-time_wp(1),awg3_s - init_eta(3));
ylabel('$\eta$ [m]');

ax2 = subplot(3,1,2);
plot(interval_t,P_fluct(:,[9:10]));
ylabel('$\tilde{p}$ [Pa]');
legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10))));

ax3 = subplot(3,1,3);
plot(interval_t, P_grad(:,7:9)/sg);
ylabel('$\nabla \tilde{p}$ [Pa/m]');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%% Plot in a single figure
plot_int = [1243,1293];
c = colororder;
pause(1)

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
sg = rho*g;

%section 1
figure;
tiledlayout(3,3,'tilespacing','compact','padding','compact');
ax1 = nexttile;
plot(time_wp-time_wp(1),awg1_s - init_eta(1),'k');
title("Section 1");
set(gca,'xticklabel',{[]})
ylabel('$\eta$ [m]');
ylim([0 0.45]);
text(0.05,0.08,'a)','Units','normalized');

ax2 = nexttile(4);
plot(interval_t,P_fluct(:,[1,2,4]));
set(gca,'xticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4))));
ylabel('$\tilde{p}$ [Pa]');
ylim([-600 650]);
colororder(ax2,[0 0.8 0.2; 0 0.5 0.12; 0 0.2 0.05]);
text(0.05,0.08,'d)','Units','normalized');

ax3 = nexttile(7);
plot(interval_t, P_grad(:,1:3)/sg);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$');
ylabel('$\nabla \tilde{p}$ [Pa/m]');
ylim([-0.3 0.45]);
colororder(ax3,[0 0.6 0.8;0 0.3 0.366]);
text(0.05,0.08,'g)','Units','normalized');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
ax1 = nexttile(2);
plot(time_wp-time_wp(1),awg2_s - init_eta(2),'k');
title("Section 2");
set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
set(gca,'yticklabel',{[]})
ylim([0 0.45]);
text(0.05,0.08,'b)','Units','normalized');

ax2 = nexttile(5);
plot(interval_t,P_fluct(:,[5:8]));
set(gca,'xticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7))),strcat('$\Delta z_b = $',num2str(probeDistToBed(8))));
% ylabel('$\tilde{p}$ [Pa]');
set(gca,'yticklabel',{[]})
ylim([-600 650]);
colororder(ax2,[0 0.8 0.2; 0 0.6 0.15; 0 0.4 0.1; 0 0.2 0.05]);
text(0.05,0.08,'e)','Units','normalized');


ax3 = nexttile(8);
plot(interval_t, P_grad(:,4:6)/sg);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$', '$\nabla \tilde{p}_{3,4}$');
% ylabel('$\nabla \tilde{p}$ [Pa/m]');
set(gca,'yticklabel',{[]})
ylim([-0.3 0.45]);
colororder(ax3,[0 0.6 0.8; 0 0.5 0.6; 0 0.3 0.366]);
text(0.05,0.08,'h)','Units','normalized');
xlabel('$t$ [s]');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
ax1 = nexttile(3);
plot(time_wp-time_wp(1),awg3_s - init_eta(3),'k');
title("Section 3");
set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
set(gca,'yticklabel',{[]})
ylim([0 0.45]);
text(0.05,0.08,'c)','Units','normalized');

ax2 = nexttile(6);
plot(interval_t,P_fluct(:,[9:10]));
set(gca,'xticklabel',{[]})
% ylabel('$\tilde{p}$ [Pa]');
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10))));
set(gca,'yticklabel',{[]})
set(gca,'yticklabel',{[]})
ylim([-600 650]);
colororder(ax2,[0 0.8 0.2; 0 0.2 0.05]);
text(0.05,0.08,'f)','Units','normalized');

ax3 = nexttile(9);
plot(interval_t, P_grad(:,7:9)/sg);
% ylabel('$\nabla \tilde{p}$ [Pa/m]');
set(gca,'yticklabel',{[]})
linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
ylim([-0.3 0.45]);
text(0.05,0.08,'i)','Units','normalized');
colororder(ax3,[0 0.5 0.6;]);
pause(1)

%%

set(groot,'defaultAxesXGrid','off')
set(groot,'defaultAxesYGrid','off')
