%% Load data and control settings
clear all;
close all;

run_nr = 79;
calibration = 1; % 1 to use calibration for stb1, 2 for stb2;
flagSaveFigures = 0;
flagPlotFigures = 1;

load('xPPT.mat');
load('zPPT_abs.mat');
load('zPPT_rel.mat');
load(strcat('calCoeffs',num2str(calibration),'.mat')); %Coefficients from the calibration
% load(strcat('AWG',num2str(run_nr),'Smooth.mat')); %Smoothed awg signals per section
load(strcat('StB_run',num2str(run_nr),'.mat'));
if run_nr > 9
    load(strcat('EC1StB_0',num2str(run_nr-14),'PPT.mat'));
elseif run_nr < 10
    load(strcat('StB2ppt_00',num2str(run_nr),'.mat'));
end
%Note that the ppt variable gives results from ppts used as wave-gauges.
load('prof_data_corrected');
profile_z = p(run_nr - 18).z;
profile_x = p(run_nr -18).x;
disp(head{run_nr - 18});

probeDistToBed = getProbeDistanceToBedWithScour(run_nr,xPPT,zPPT_abs,p);

rho = 1000;
g = 9.81;

[ppt_t,ppt_p] = getPPTData_1(PPT_data);
P = getPressureFromSignal(ppt_p,A,B);

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

%% Pressure gradients
% The pressure gradients are based on the mean pressure in an interval

interval  = [1000 1800];
[~,int_a] = min(abs(ppt_t - interval(1)));
[~,int_b] = min(abs(ppt_t - interval(2)));
intervalIdx = [int_a, int_b];
interval_t = ppt_t(int_a:int_b);

P_mean = mean(P(int_a:int_b,:),1);
P_fluct = P(int_a:int_b,:) - P_mean;

P_grad_abs = [(P_fluct(:,2) - P_fluct(:,1)),...
    (P_fluct(:,4) - P_fluct(:,2)),...
    (nan(size(P_fluct(:,3)))),...
    ...
    (P_fluct(:,6) - P_fluct(:,5)),...
    (P_fluct(:,7) - P_fluct(:,6)),...
    (P_fluct(:,8) - P_fluct(:,7)),...
    ...
    (P_fluct(:,10) - P_fluct(:,9)),...
    (nan(size(P_fluct(:,11)))),...
    (nan(size(P_fluct(:,12))))];

dzPPT = [zPPT_abs(2)-zPPT_abs(1),...
    zPPT_abs(4)-zPPT_abs(2),...
    nan,...
    zPPT_abs(6)-zPPT_abs(5),...
    zPPT_abs(7)-zPPT_abs(6),...
    zPPT_abs(8)-zPPT_abs(7),...
    zPPT_abs(10)-zPPT_abs(9),...
    nan,...
    nan];

P_grad = P_grad_abs./dzPPT;

legendTxt = ["0.303 - 0.203";...
    "0.203 - 0.173";...
    "";...
    "0.457 - 0.347";...
    "0.347 - 0.297";...
    "0.297 - 0.212";...
    "0.528 - 0.411";...
    "";...
    ""];

legendTxt = ["0.303 - 0.203";...
    "0.203 - 0.173";...
    "";...
    "0.457 - 0.347";...
    "0.347 - 0.297";...
    "0.297 - 0.212";...
    "0.528 - 0.411";...
    "";...
    ""];

%% AWG data (old)

% awg_idx = [20,19,14];
% 
% Fs = 40; % Hz, frequency of RWG, AWG and PPT
% % Cut-off frequency for AWG (instrumentation noise)
% Fc_hf = 8; %(highfreq) freq of short waves higher frequency limit
% [B,A] = butter(4,Fc_hf/(Fs/2));
% 
% awg1 = AWG(:,awg_idx(1));
% awg2 = AWG(:,awg_idx(2));
% awg3 = AWG(:,awg_idx(3));
% awg1_s = filtfilt(B,A,awg1);
% awg2_s = filtfilt(B,A,awg2);
% awg3_s = filtfilt(B,A,awg3);

%% Analysis of wave gauges
% For section 1
% x ppt is 78.23
% wave gauges 20 (x = 78.01) and 21 (x = 78.74)

awg_idx = [20,19,14]; %C,B,A

Fs = 40; % Hz, frequency of RWG, AWG and PPT
% Cut-off frequency for AWG (instrumentation noise)
Fc_hf = 8; %(highfreq) freq of short waves higher frequency limit
[B,A] = butter(4,Fc_hf/(Fs/2));

%Get the time lags
[pptlag1,pptlag2,pptlag3] = getPPTTimeLags(time_wp,AWG);

%Load the wave gauges used for the pressure
[awgTime,awg1_s,awg2_s,awg3_s] = getAWGInInterval(AWG,time_wp,awg_idx,interval);

h_av1 = mean(awg1_s);
h_av2 = mean(awg2_s);
h_av3 = mean(awg3_s);

p0_1 = rho*g*awg1_s;
p0_2 = rho*g*awg2_s;
p0_3 = rho*g*awg3_s;

%% Plot pressure and pressure gradients under waves
% plot_int = [1003,1043];
% 
% init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
% sg = rho*g;
% 
% if flagPlotFigures
%     %section 1
%     figure
%     ax1 = subplot(3,1,1);
%     plot(time_wp-time_wp(1),awg1_s - init_eta(1));
%     ylabel('$\eta$ [m]');
%     
%     ax2 = subplot(3,1,2);
%     plot(interval_t,P_fluct(:,[1,2,4]));
%     legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4))));
%     ylabel('$\tilde{p}$ [Pa]');
%     
%     ax3 = subplot(3,1,3);
%     plot(interval_t, P_grad(:,1:3)/sg);
%     legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$');
%     ylabel('$\nabla \tilde{p}$ [Pa/m]');
%     
%     linkaxes([ax1 ax2 ax3],'x');
%     xlim(plot_int);
%     pause(1)
%     
%     %section 1
%     figure
%     ax1 = subplot(3,1,1);
%     plot(time_wp-time_wp(1),awg2_s - init_eta(2));
%     ylabel('$\eta$ [m]');
%     
%     ax2 = subplot(3,1,2);
%     plot(interval_t,P_fluct(:,[5:8]));
%     legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7))),strcat('$\Delta z_b = $',num2str(probeDistToBed(8))));
%     ylabel('$\tilde{p}$ [Pa]');
%     
%     ax3 = subplot(3,1,3);
%     plot(interval_t, P_grad(:,4:6)/sg);
%     legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$', '$\nabla \tilde{p}_{3,4}$');
%     ylabel('$\nabla \tilde{p}$ [Pa/m]');
%     
%     linkaxes([ax1 ax2 ax3],'x');
%     xlim(plot_int);
%     pause(1)
%     
%     %section 1
%     figure
%     ax1 = subplot(3,1,1);
%     plot(time_wp-time_wp(1),awg3_s - init_eta(3));
%     ylabel('$\eta$ [m]');
%     
%     ax2 = subplot(3,1,2);
%     plot(interval_t,P_fluct(:,[9:10]));
%     ylabel('$\tilde{p}$ [Pa]');
%     legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10))));
%     
%     
%     ax3 = subplot(3,1,3);
%     plot(interval_t, P_grad(:,7:9)/sg);
%     ylabel('$\nabla \tilde{p}$ [Pa/m]');
%     
%     linkaxes([ax1 ax2 ax3],'x');
%     xlim(plot_int);
%     pause(1)
% end
% 
% %% Plot in a single figure
% plot_int = [1003,1043];
% 
% set(groot,'defaultAxesXGrid','on')
% set(groot,'defaultAxesYGrid','on')
% 
% init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
% sg = rho*g;
% 
% if flagPlotFigures
%     %section 1
%     figure;
%     tiledlayout(2,3,'tilespacing','compact','padding','compact');
%     ax1 = nexttile
%     plot(time_wp-time_wp(1),awg1_s - init_eta(1));
%     set(gca,'xticklabel',{[]})
%     ylabel('$\eta$ [m]');
%     ylim([0 0.45]);
%     title('Section 1');
%     text(0.05,0.92,'a)','Units','normalized');
%     
%     ax2 = nexttile(4);
%     plot(interval_t,P_fluct(:,[1,2,4]));
% %     set(gca,'xticklabel',{[]})
%     legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1)),' m'),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2)),' m'),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4)),' m'),'location','southoutside');
%     ylabel('$\tilde{p}$ [Pa]');
%     text(0.05,0.92,'d)','Units','normalized');
%     linkaxes([ax1 ax2],'x');
%     xlim(plot_int);
%     ylim([-600 650]);
%     xlabel('t [s]');
%     pause(1)
%     
%     %section 1
%     ax1 = nexttile(2);
%     plot(time_wp-time_wp(1),awg2_s - init_eta(2));
%     set(gca,'xticklabel',{[]})
%     set(gca,'yticklabel',{[]})
%     % ylabel('$\eta$ [m]');
%     ylim([0 0.45]);
%     text(0.05,0.92,'b)','Units','normalized');
%     title('Section 2');
%     
%     ax2 = nexttile(5);
%     plot(interval_t,P_fluct(:,[5:8]));
%      set(gca,'yticklabel',{[]})
%     legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5)),' m'),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6)),' m'),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7)),' m'),strcat('$\Delta z_b = $',num2str(probeDistToBed(8)),' m'),'location','southoutside');
%     % ylabel('$\tilde{p}$ [Pa]');
%     text(0.05,0.92,'e)','Units','normalized');
%     linkaxes([ax1 ax2],'x');
%     xlim(plot_int);
%     ylim([-600 650]);
%     xlabel('t [s]');
%     pause(1)
%     
%     %section 1
%     ax1 = nexttile(3);
%     plot(time_wp-time_wp(1),awg3_s - init_eta(3));
%     set(gca,'xticklabel',{[]})
%      set(gca,'yticklabel',{[]})
%     % ylabel('$\eta$ [m]');
%     ylim([0 0.45]);
%     text(0.05,0.92,'c)','Units','normalized');
%     title('Section 3');
%      
%     ax2 = nexttile(6);
%     plot(interval_t,P_fluct(:,[9:10]));
%      set(gca,'yticklabel',{[]})
%     % ylabel('$\tilde{p}$ [Pa]');
%     legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9)),' m'),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10)),' m'),'location','southoutside');
%     text(0.05,0.92,'f)','Units','normalized');    
%     linkaxes([ax1 ax2],'x');
%     xlim(plot_int);
%     ylim([-600 650]);
%     
%     pause(1)
% end

%% Plot spectral analysis of pressures
ppt_f = 100;
T_length = interval(2)-interval(1);
ppt_L = length(P_fluct);
spectrum_f = (1:ppt_L)*(ppt_f/ppt_L);
P_spectral = fft(P_fluct);

awg1_interp = interp1(awgTime,awg1_s,interval_t);
awg1_interp(isnan(awg1_interp))=0;
awg_spectral_PSample = fft(awg1_interp);
% 
% figure;
% ax1 = subplot(3,1,1);
% plot(spectrum_f,abs(P_spectral(:,1)));
% hold on;
% plot(spectrum_f,abs(P_spectral(:,2)));
% plot(spectrum_f,abs(P_spectral(:,4)));
% 
% ax2 = subplot(3,1,2);
% plot(spectrum_f,180/pi*unwrap(angle(P_spectral(:,1))));
% hold on;
% plot(spectrum_f,180/pi*unwrap(angle(P_spectral(:,2))));
% plot(spectrum_f,180/pi*unwrap(angle(P_spectral(:,4))));
% 
% ax3 = subplot(3,1,3);
% plot(spectrum_f,180/pi*(angle(P_spectral(:,1))));
% hold on;
% plot(spectrum_f,180/pi*(angle(P_spectral(:,2))));
% plot(spectrum_f,180/pi*(angle(P_spectral(:,4))));
% linkaxes([ax1,ax2,ax3],'x');
% xlim([0,0.5]);
% 
% % figure;
% % plot(spectrum_f,unwrap(angle(P_spectral(:,2))-angle(P_spectral(:,1))));
% % xlim([0,0.5]);
% % figure;
% % plot(spectrum_f,unwrap(angle(P_spectral(:,4))-angle(P_spectral(:,2))));
% % xlim([0,0.5]);
% % 
% % figure;
% % plot(spectrum_f,unwrap(angle(P_spectral(:,1))-angle(awg_spectral_PSample)));
% % hold on;
% % plot(spectrum_f,unwrap(angle(P_spectral(:,2))-angle(awg_spectral_PSample)));
% % plot(spectrum_f,unwrap(angle(P_spectral(:,4))-angle(awg_spectral_PSample)-2*pi));
% % xlim([0,0.5]);
% 
% figure;
% plot(spectrum_f,mod(-angle(P_spectral(:,1))+angle(awg_spectral_PSample),2*pi),'*');
% hold on;
% plot(spectrum_f,mod(-angle(P_spectral(:,2))+angle(awg_spectral_PSample),2*pi),'*');
% plot(spectrum_f,mod(-angle(P_spectral(:,4))+angle(awg_spectral_PSample),2*pi),'*');
% xlim([0,0.5]);
%%
awg_C = AWG(:,20);
awg_B = AWG(:,19);
awg_A = AWG(:,14);

ppt_f = 100;
T_length = interval(2)-interval(1);
ppt_L = length(P_fluct);
spectrum_f = (1:ppt_L)*(ppt_f/ppt_L);
P_spectral = fft(P_fluct);
nr = length(P_fluct);

% awg_f = Fs;
% awg_s_L = length(awg1_s);
% spectrum_awg1 = (1:awg_s_L)*(awg_f/awg_s_L);
% awg_spectral = fft(awg1_s);

% awg_interp_C = interp1(awgTime,awg1_s,interval_t);
% awg_interp_C(isnan(awg1_interp))=0;
% awg_spectral_PSample = fft(awg_interp_C);

awg_f = Fs;
awg_s_L = length(awg_C);
spectrum_awg1 = (1:awg_s_L)*(awg_f/awg_s_L);
awg_spectral_C = fft(awg_C);
awg_spectral_B = fft(awg_B);
awg_spectral_A = fft(awg_A);


figure;
tiledlayout(2,1,'tilespacing','compact','padding','compact');
ax1 = nexttile(2)
semilogy(spectrum_f,2*abs(P_spectral(:,1))/nr);
hold on;
semilogy(spectrum_f,2*abs(P_spectral(:,2))/nr);
semilogy(spectrum_f,2*abs(P_spectral(:,4))/nr);
ylim([1e-2,1e3]);
xlim([0,0.5]);
ylabel('[Pa/Hz]');
grid on;
xlabel('Frequency [Hz]');
legend('$C_3$','$C_2$','$C_1$');
text(0.05,0.9,'b)','units','normalized');

semilogy([1,1]*(1/21),[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
semilogy([1,1]*11/42.75,[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
semilogy([1,1]*13/42.75,[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);

text(0.06,300,"$f_g$");
text(0.26,300,"$f_1$");
text(0.31,300,"$f_2$");

ax1 = nexttile(1)
semilogy(spectrum_awg1,2*abs(awg_spectral_C)/awg_s_L,'k');
hold on;
xlim([0,0.5]);
ylim([1e-5,0.05]);
ylabel('[m/Hz]');
grid on;
text(0.05,0.9,'a)','units','normalized');
semilogy([1,1]*(1/21),[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
semilogy([1,1]*11/42.75,[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
semilogy([1,1]*13/42.75,[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
set(gca,'xticklabel',{[]})


% subplot(3,1,3)
% plot(spectrum_f,mod(-angle(P_spectral(:,1))+angle(awg_spectral_PSample),2*pi),'-');
% hold on;
% plot(spectrum_f,mod(-angle(P_spectral(:,2))+angle(awg_spectral_PSample),2*pi),'-');
% plot(spectrum_f,mod(-angle(P_spectral(:,4))+angle(awg_spectral_PSample),2*pi),'-');
% 
% semilogy([1,1]*(1/21),[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
% semilogy([1,1]*11/42.75,[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
% semilogy([1,1]*13/42.75,[1e-10,1e6],'HandleVisibility','off','color',[0.3,0.7,0.3]);
% ylim([0,2*pi]);
% xlim([0,0.5]);

%%
p0_spectral_C = awg_spectral_C*rho*g;
p0_spectral_B = awg_spectral_B*rho*g;
p0_spectral_A = awg_spectral_A*rho*g;

% P_spectral(:,1))/nr
figure;

plot(spectrum_awg1,2*abs(p0_spectral_C)/awg_s_L);
hold on;
plot(spectrum_f,2*abs(P_spectral(:,1))/nr);
plot(spectrum_f,2*abs(P_spectral(:,2))/nr);
plot(spectrum_f,2*abs(P_spectral(:,4))/nr);

title("Spectrum of p($\hat{z}$) at loc C")
legend("0","0.3","0.4","0.65");
xlabel('Hz')
ylabel('Pa/s')
xlim([0.2,0.4]);
ylim([0,40]);

figure;
plot(spectrum_awg1,2*abs(p0_spectral_B)/awg_s_L);
hold on;
plot(spectrum_f,2*abs(P_spectral(:,5))/nr);
plot(spectrum_f,2*abs(P_spectral(:,6))/nr);
plot(spectrum_f,2*abs(P_spectral(:,7))/nr);
plot(spectrum_f,2*abs(P_spectral(:,8))/nr);

title("Spectrum of p($\hat{z}$) at loc B")
legend("0","0.35","0.39","436","0.52");
xlabel('Hz')
ylabel('Pa/s')
xlim([0.2,0.4]);
ylim([0,40]);

figure;
plot(spectrum_awg1,2*abs(p0_spectral_A)/awg_s_L);
hold on;
plot(spectrum_f,2*abs(P_spectral(:,9))/nr);
plot(spectrum_f,2*abs(P_spectral(:,10))/nr);

title("Spectrum of p($\hat{z}$) at loc A")
legend("0","0.4","0.5");
xlabel('Hz')
ylabel('Pa/s')
xlim([0.2,0.4]);
ylim([0,40]);


%%
figure;

plot(spectrum_awg1,(angle(p0_spectral_C)));
hold on;
plot(spectrum_f,(angle(P_spectral(:,1))));
plot(spectrum_f,(angle(P_spectral(:,2))));
plot(spectrum_f,(angle(P_spectral(:,4))));
xlim([0.2,0.4]);
title("loc C")

figure;
plot(spectrum_awg1,(angle(p0_spectral_B)));
hold on;
plot(spectrum_f,(angle(P_spectral(:,5))));
plot(spectrum_f,(angle(P_spectral(:,6))));
plot(spectrum_f,(angle(P_spectral(:,7))));
plot(spectrum_f,(angle(P_spectral(:,8))));
xlim([0.2,0.4]);
title("loc B")

figure;
plot(spectrum_awg1,(angle(p0_spectral_A)));
hold on;
plot(spectrum_f,(angle(P_spectral(:,9))));
plot(spectrum_f,(angle(P_spectral(:,10))));
xlim([0.2,0.4]);

title("Loc A");

figure;
plot(spectrum_f,(angle(P_spectral(:,9)./P_spectral(:,10))));


