% Analyze surface elevations for case 1

calibration = 1; % 1 to use probe calibration for stb1, 2 for stb2;
flagSaveFigures = 0;

load('xPPT.mat');
load('zPPT_abs.mat');
load('zPPT_rel.mat');
load(strcat('../calCoeffs',num2str(calibration),'.mat')); %Coefficients from the calibration
% load(strcat('AWG',num2str(run_nr),'Smooth.mat')); %Smoothed awg signals per section
load(strcat('StB_run',num2str(run_nr),'.mat'));
if run_nr > 9
    load(strcat('EC1StB_0',num2str(run_nr-14),'PPT.mat'));
elseif run_nr < 10
    load(strcat('StB2ppt_00',num2str(run_nr),'.mat'));
end
%Note that the ppt variable gives results from ppts used as wave-gauges.
load('prof_data_corrected');
profile_z = p(run_nr - 18).z;
profile_x = p(run_nr -18).x;
disp(head{run_nr - 18});

probeDistToBed = getProbeDistanceToBedWithScour(run_nr,xPPT,zPPT_abs,p);

rho = 1000;
g = 9.81;

[ppt_t,ppt_p] = getPPTData_1(PPT_data);
P = getPressureFromSignal(ppt_p,A,B);

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

%% Pressure gradients
% The pressure gradients are based on the mean pressure in an interval

% interval  = [1003.77 1775.69];
interval  = [1000 1800];
[~,int_a] = min(abs(ppt_t - interval(1)));
[~,int_b] = min(abs(ppt_t - interval(2)));
intervalIdx = [int_a, int_b];
interval_t = ppt_t(int_a:int_b);

P_mean = mean(P(int_a:int_b,:),1);
P_fluct = P(int_a:int_b,:) - P_mean;

P_grad_abs = [(P_fluct(:,2) - P_fluct(:,1)),...
    (P_fluct(:,4) - P_fluct(:,2)),...
    (nan(size(P_fluct(:,3)))),...
    ...
    (P_fluct(:,6) - P_fluct(:,5)),...
    (P_fluct(:,7) - P_fluct(:,6)),...
    (P_fluct(:,8) - P_fluct(:,7)),...
    ...
    (P_fluct(:,10) - P_fluct(:,9)),...
    (nan(size(P_fluct(:,11)))),...
    (nan(size(P_fluct(:,12))))];

dzPPT = [zPPT_abs(2)-zPPT_abs(1),...
    zPPT_abs(4)-zPPT_abs(2),...
    nan,...
    zPPT_abs(6)-zPPT_abs(5),...
    zPPT_abs(7)-zPPT_abs(6),...
    zPPT_abs(8)-zPPT_abs(7),...
    zPPT_abs(10)-zPPT_abs(9),...
    nan,...
    nan];

P_grad = P_grad_abs./dzPPT;

legendTxt = ["0.303 - 0.203";...
    "0.203 - 0.173";...
    "";...
    "0.457 - 0.347";...
    "0.347 - 0.297";...
    "0.297 - 0.212";...
    "0.528 - 0.411";...
    "";...
    ""];
%% Prepare for analysis

awg_idx = [20,19,14];

Fs = 40; % Hz, frequency of RWG, AWG and PPT
% Cut-off frequency for AWG (instrumentation noise)
Fc_hf = 8; %(highfreq) freq of short waves higher frequency limit
[B,A] = butter(4,Fc_hf/(Fs/2));

%Get the time lags
[pptlag1,pptlag2,pptlag3] = getPPTTimeLags(time_wp,AWG);

%Load the wave gauges used for the pressure
[awgTime,awg1_s,awg2_s,awg3_s] = getAWGInInterval(AWG,time_wp,awg_idx,interval);
h_av1 = mean(awg1_s);
h_av2 = mean(awg2_s);
h_av3 = mean(awg3_s);

p0_1 = rho*g*awg1_s;
p0_2 = rho*g*awg2_s;
p0_3 = rho*g*awg3_s;

awg_f = 40;
Tawg_length = interval(2)-interval(1);

awg_L = length(awg1_s);
spectrumP0_f = [0:ceil(awg_L/2)-1 , -floor(awg_L/2):-1]'*(awg_f/awg_L);
p0_1_spectral = fft(p0_1);
p0_2_spectral = fft(p0_2);
p0_3_spectral = fft(p0_3);

ppt_f = 100;
T_length = interval(2)-interval(1);
ppt_L = length(P_fluct);
spectrum_f = (1:ppt_L)*(ppt_f/ppt_L);
P_spectral = fft(P_fluct);

%% Do the calibration
aTry = 0:0.2:80; % Try values of a
dzTry = -0.2:0.005:0.2;
P_fluct_interp = interp1(interval_t,P_fluct,awgTime,'linear','extrap');

bestR = [inf, inf, inf];
bestR_a = [];
bestR_dz = [];
bestRMSE = [inf, inf, inf];
bestRMSE_a = [];
bestRMSE_dz = [];

% h_av1 = 0.16;
% h_av2 = 0.16;
% h_av3 = 0.16;

omega = spectrumP0_f*2*pi;
k = omega./sqrt(g*[h_av1,h_av2,h_av3]);
N = length(omega);

for a = aTry
    for  dz = dzTry
        kp = k.*sqrt(1+(1i*omega.*a)./(k.*k));
        kp(kp<0) = -1*kp(kp<0);
        kp(1,:)=0;
        
        p1 = @(z) ifft(p0_1_spectral.*exp(-kp(:,1)*(z+dz)));
        p2 = @(z) ifft(p0_2_spectral.*exp(-kp(:,2)*(z+dz)));
        p3 = @(z) ifft(p0_3_spectral.*exp(-kp(:,3)*(z+dz)));
        
        p_model1 = [p1(probeDistToBed(1)),p1(probeDistToBed(2)),p1(probeDistToBed(4))];
        p_model2 = [p2(probeDistToBed(5)),p2(probeDistToBed(6)),p2(probeDistToBed(7)),p2(probeDistToBed(8))];
        p_model3 = [p3(probeDistToBed(9)),p3(probeDistToBed(10))];
        
        p_model1_mean = mean(p_model1);
        p_model2_mean = mean(p_model2);
        p_model3_mean = mean(p_model3);
        
        RMSE = [sqrt(sum((p_model1-p_model1_mean-P_fluct_interp(:,[1,2,4])).^2))/sqrt(N)...
            sqrt(sum((p_model2-p_model2_mean-P_fluct_interp(:,[5,6,7,8])).^2))/sqrt(N)...
            sqrt(sum((p_model3-p_model3_mean-P_fluct_interp(:,[9,10])).^2))/sqrt(N)];
        
        RMSE_sum = [rms(RMSE(1:3)), rms(RMSE(4:7)), rms(RMSE(8:9))];
        
        corr = corrcoef([p_model1 p_model2 p_model3 P_fluct_interp]);
        R2 = [corr(1,10), corr(2,11), corr(3,13), corr(4,14),corr(5,15),corr(6,16),corr(7,17),corr(8,18),corr(9,19)].^2;
        R2_sum = [rms(1-R2(1:3)), rms(1-R2(4:7)), rms(1-R2(8:9))];
        
        for i = 1:3
            if (RMSE_sum(i) < bestRMSE(i))
                bestRMSE(i) = RMSE_sum(i);
                bestRMSE_a(i) = a;
                bestRMSE_dz(i) = dz;
            end
            
            if (R2_sum(i) < bestR(i))
                bestR(i) = R2_sum(i);
                bestR_a(i) = a;
                bestR_dz(i) = dz;
            end
            
        end
    end
    
    %     disp(strcat('Calibration for a = ',num2str(a),' is done'));
end



% a1 = 30;
% a2 = 30;
% a3 = 30;
%
% kp1 = k1.*sqrt(1+(1i*omega*a1)./(k1.*k1));
% kp2 = k2.*sqrt(1+(1i*omega*a2)./(k2.*k2));
% kp3 = k3.*sqrt(1+(1i*omega*a3)./(k3.*k3));
%
% kp1(kp1<0) = kp1(kp1<0)* -1;
% kp2(kp2<0) = kp2(kp2<0)* -1;
% kp3(kp3<0) = kp3(kp3<0)* -1;
%
% kp1(1) = 0;
% kp2(1) = 0;
% kp3(1) = 0;
%
% p1 = @(z) ifft(p0_1_spectral.*exp(-kp1*z));
% p2 = @(z) ifft(p0_2_spectral.*exp(-kp2*z));
% p3 = @(z) ifft(p0_3_spectral.*exp(-kp3*z));
