function [awgTime,awg1_s,awg2_s,awg3_s] = getAWGInInterval(AWG,time_wp,awg_idx,interval)
%getAWGInInterval: return wave gauges and time vector within the chosen
%interval. Note that the average bed level is removed from the signal. Also
%the time lags are incorporated
[B,A] = getFilterCoeffs();

[lag1,lag2,lag3] = getPPTTimeLags(time_wp,AWG);

awg1 = AWG(:,awg_idx(1)); 
awg2 = AWG(:,awg_idx(2)); 
awg3 = AWG(:,awg_idx(3)); 
awg1_s = filtfilt(B,A,awg1)-2.47; % This gives the absolute surface elevation to the still water line, does not take bed level into account
awg2_s = filtfilt(B,A,awg2)-2.47;
awg3_s = filtfilt(B,A,awg3)-2.47;

awgTime = time_wp-time_wp(1);
[~,int_a] = min(abs(awgTime - interval(1) - lag1));
[~,int_b] = min(abs(awgTime - interval(2) - lag1));

awg1_s = awg1_s(int_a:int_b);

[~,int_a] = min(abs(awgTime - interval(1) - lag2));
[~,int_b] = min(abs(awgTime - interval(2) - lag2));

awg2_s = awg2_s(int_a:int_b);

[~,int_a] = min(abs(awgTime - interval(1) - lag3));
[~,int_b] = min(abs(awgTime - interval(2) - lag3));

awg3_s = awg3_s(int_a:int_b);

awg1_s = awg1_s - mean(movmin(awg1_s,10000));
awg2_s = awg2_s - mean(movmin(awg2_s,10000));
awg3_s = awg3_s - mean(movmin(awg3_s,10000));

awgTime = awgTime(int_a:int_b);
end

