% Analyze surface elevations for case 1

run_nr = 79;
% run_nr = 91;
calibration = 1; % 1 to use probe calibration for stb1, 2 for stb2;
flagSaveFigures = 0;
flagDoModelCalibration = 0; %Flag to specify if the user wants to use the
% calibration script for determining calibration constants. If 0, please
% specify calibration constants a1, a2, a3.

load('xPPT.mat');
load('zPPT_abs.mat');
load('zPPT_rel.mat');
load(strcat('calCoeffs',num2str(calibration),'.mat')); %Coefficients from the probe calibration.
% ^^^^^^^^^^ If error run from working directory EC1_slope!! ^^^^^^^^^^
% load(strcat('AWG',num2str(run_nr),'Smooth.mat')); %Smoothed awg signals per section
load(strcat('StB_run',num2str(run_nr),'.mat'));
if run_nr > 9
    load(strcat('EC1StB_0',num2str(run_nr-14),'PPT.mat'));
elseif run_nr < 10
    load(strcat('StB2ppt_00',num2str(run_nr),'.mat'));
end
%Note that the ppt variable gives results from ppts used as wave-gauges.
load('prof_data_corrected');
profile_z = p(run_nr - 18).z;
profile_x = p(run_nr -18).x;
disp(head{run_nr - 18});

probeDistToBed = getProbeDistanceToBedWithScour(run_nr,xPPT,zPPT_abs,p);

rho = 1000;
g = 9.81;

[ppt_t,ppt_p] = getPPTData_1(PPT_data);
P = getPressureFromSignal(ppt_p,A,B);

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

if (flagDoModelCalibration)
   doCalibration;
   a1 = bestRMSE_a(1);
   a2 = bestRMSE_a(2);
   a3 = bestRMSE_a(3);
   disp('Model calibration coefficients: ');
   disp([a1,a2,a3]);
end

if(~flagDoModelCalibration)
    disp("WARNING: Using default model calibration coefficients");
    a1 = 39.6
    a2 = 37.7
    a3 = 25.9
end

%% Pressure gradients
% The pressure gradients are based on the mean pressure in an interval

% interval  = [1003.77 1775.69];
interval  = [1000 1800];
[~,int_a] = min(abs(ppt_t - interval(1)));
[~,int_b] = min(abs(ppt_t - interval(2)));
intervalIdx = [int_a, int_b];
interval_t = ppt_t(int_a:int_b);

P_mean = mean(P(int_a:int_b,:),1);
P_fluct = P(int_a:int_b,:) - P_mean;

P_grad_abs = [(P_fluct(:,2) - P_fluct(:,1)),...
    (P_fluct(:,4) - P_fluct(:,2)),...
    (nan(size(P_fluct(:,3)))),...
    ...
    (P_fluct(:,6) - P_fluct(:,5)),...
    (P_fluct(:,7) - P_fluct(:,6)),...
    (P_fluct(:,8) - P_fluct(:,7)),...
    ...
    (P_fluct(:,10) - P_fluct(:,9)),...
    (nan(size(P_fluct(:,11)))),...
    (nan(size(P_fluct(:,12))))];

dzPPT = [zPPT_abs(2)-zPPT_abs(1),...
    zPPT_abs(4)-zPPT_abs(2),...
    nan,...
    zPPT_abs(6)-zPPT_abs(5),...
    zPPT_abs(7)-zPPT_abs(6),...
    zPPT_abs(8)-zPPT_abs(7),...
    zPPT_abs(10)-zPPT_abs(9),...
    nan,...
    nan];

P_grad = P_grad_abs./dzPPT;

legendTxt = ["0.303 - 0.203";...
    "0.203 - 0.173";...
    "";...
    "0.457 - 0.347";...
    "0.347 - 0.297";...
    "0.297 - 0.212";...
    "0.528 - 0.411";...
    "";...
    ""];
%% Analysis of wave gauges
% For section 1
% x ppt is 78.23
% wave gauges 20 (x = 78.01) and 21 (x = 78.74)

awg_idx = [20,19,14];

Fs = 40; % Hz, frequency of RWG, AWG and PPT
% Cut-off frequency for AWG (instrumentation noise)
Fc_hf = 8; %(highfreq) freq of short waves higher frequency limit
[B,A] = butter(4,Fc_hf/(Fs/2));

%Get the time lags
[pptlag1,pptlag2,pptlag3] = getPPTTimeLags(time_wp,AWG);

%Load the wave gauges used for the pressure
[awgTime,awg1_s,awg2_s,awg3_s] = getAWGInInterval(AWG,time_wp,awg_idx,interval);

h_av1 = mean(awg1_s);
h_av2 = mean(awg2_s);
h_av3 = mean(awg3_s);

p0_1 = rho*g*awg1_s;
p0_2 = rho*g*awg2_s;
p0_3 = rho*g*awg3_s;

%% Apply pressure model (Guest and Hay)

% h_av1 = 0.16;
% h_av2 = 0.16;
% h_av3 = 0.16;

plot_int = [1243,1293];

% frequency=[0:ceil(nbrSamples/2)-1,-floor(nbrSamples/2):-1]'/sampleInterval/nbrSamples;
% TODO: From here the awg signal needs to be aligned with the ppt signal.
awg_f = 40;
Tawg_length = interval(2)-interval(1);

awg_L = length(awg1_s);
spectrumP0_f = [0:ceil(awg_L/2)-1 , -floor(awg_L/2):-1]'*(awg_f/awg_L);
p0_1_spectral = fft(p0_1);
p0_2_spectral = fft(p0_2);
p0_3_spectral = fft(p0_3);

ppt_f = 100;
T_length = interval(2)-interval(1);
ppt_L = length(P_fluct);
spectrum_f = (1:ppt_L)*(ppt_f/ppt_L);
P_spectral = fft(P_fluct);

omega = spectrumP0_f*2*pi;
% omega(omega<0) = -1*omega(omega<0);
k1 = omega/sqrt(g*h_av1);
k2 = omega/sqrt(g*h_av2);
k3 = omega/sqrt(g*h_av3);

kp1 = k1.*sqrt(1+(1i*omega*a1)./(k1.*k1));
kp2 = k2.*sqrt(1+(1i*omega*a2)./(k2.*k2));
kp3 = k3.*sqrt(1+(1i*omega*a3)./(k3.*k3));

kp1(kp1<0) = kp1(kp1<0)* -1;
kp2(kp2<0) = kp2(kp2<0)* -1;
kp3(kp3<0) = kp3(kp3<0)* -1;

kp1(1) = 0;
kp2(1) = 0;
kp3(1) = 0;

p1 = @(z) ifft(p0_1_spectral.*exp(-kp1*z));
p2 = @(z) ifft(p0_2_spectral.*exp(-kp2*z));
p3 = @(z) ifft(p0_3_spectral.*exp(-kp3*z));

P_fluct_interp = interp1(interval_t,P_fluct,awgTime,'linear','extrap');
N = length(P_fluct_interp);

p_model1 = [p1(probeDistToBed(1)),p1(probeDistToBed(2)),p1(probeDistToBed(4))];
p_model2 = [p2(probeDistToBed(5)),p2(probeDistToBed(6)),p2(probeDistToBed(7)),p2(probeDistToBed(8))];
p_model3 = [p3(probeDistToBed(9)),p3(probeDistToBed(10))];

p_model1_mean = mean(p_model1);
p_model2_mean = mean(p_model2);
p_model3_mean = mean(p_model3);

%% Statistical metrics of pressures

RMSE = [sqrt(sum((p_model1-p_model1_mean-P_fluct_interp(:,[1,2,4])).^2))/sqrt(N)...
    sqrt(sum((p_model2-p_model2_mean-P_fluct_interp(:,[5,6,7,8])).^2))/sqrt(N)...
    sqrt(sum((p_model3-p_model3_mean-P_fluct_interp(:,[9,10])).^2))/sqrt(N)];

RMSE_stdv = [std(p_model1),std(p_model2),std(p_model3)];

RMSE_n = RMSE./RMSE_stdv;

RMSE_sum = [rms(RMSE(1:3)), rms(RMSE(4:7)), rms(RMSE(8:9))];

corr = corrcoef([p_model1 p_model2 p_model3 P_fluct_interp]);
R2 = [corr(1,10), corr(2,11), corr(3,13), corr(4,14),corr(5,15),corr(6,16),corr(7,17),corr(8,18),corr(9,19)].^2;
R2_sum = [rms(1-R2(1:3)), rms(1-R2(4:7)), rms(1-R2(8:9))];

%% Model pressure gradients

dp1 = @(z) ifft(-kp1.*p0_1_spectral.*exp(-kp1*z));
dp2 = @(z) ifft(-kp2.*p0_2_spectral.*exp(-kp2*z));
dp3 = @(z) ifft(-kp3.*p0_3_spectral.*exp(-kp3*z));

dp1_z = [probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2,...
    probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2];
dp2_z = [probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2,...
    probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2,...
    probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2];
dp3_z = probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2;

%% Statistical metrics of gradients

P_grad_interp = interp1(interval_t,P_grad,awgTime,'linear','extrap');
N = length(P_grad_interp);

RMSEgrad = [sqrt(sum((P_grad_interp(:,[1,2])+dp1(dp1_z)).^2))/sqrt(N)...
    sqrt(sum((P_grad_interp(:,[4,5,6])+dp2(dp2_z)).^2))/sqrt(N)...
    sqrt(sum((P_grad_interp(:,[7])+dp3(dp3_z)).^2))/sqrt(N)];

RMSEgrad_stdv = [std(P_grad_interp(:,[1,2])), std(P_grad_interp(:,[4,5,6])), std(P_grad_interp(:,[7]))];

RMSEgrad_n = RMSEgrad./RMSEgrad_stdv;

RMSEgrad_sum = [rms(RMSEgrad(1:2)), rms(RMSEgrad(3:5)), rms(RMSEgrad(6))];

corr = corrcoef([dp1(dp1_z) dp2(dp2_z) dp3(dp3_z) P_grad_interp(:,[1,2,4,5,6,7])]);
R2_dp = [corr(1,7), corr(2,8), corr(3,9), corr(4,10),corr(5,11),corr(6,12)].^2;
% R2_sum = [rms(1-R2(1:3)), rms(1-R2(4:7)), rms(1-R2(8:9))];

%% Plot in a single figure
plot_int = [1243,1293];
c = colororder;
pause(1)

wdth = 2;
mrkr = '-.';
trsp = 0.3;

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
sg = rho*g;

dp1_z = [probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2,...
    probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2];
dp2_z = [probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2,...
    probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2,...
    probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2];
dp3_z = probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2;


%section 1
figure;
tiledlayout(4,3,'tilespacing','compact','padding','compact');
ax1 = nexttile;
plot(awgTime,awg1_s,'k');
title("Section 1");
set(gca,'xticklabel',{[]})
ylabel('$\eta$ [m]');
ylim([0 0.45]);
text(0.05,0.08,'a)','Units','normalized');
alpha(0.5);

ax2 = nexttile(4);
plt = plot(interval_t,P_fluct(:,[1,2,4]),'LineWidth',wdth);
hold on;
plot(awgTime,p1(probeDistToBed(1))-p_model1_mean(1),mrkr);
plot(awgTime,p1(probeDistToBed(2))-p_model1_mean(2),mrkr);
plot(awgTime,p1(probeDistToBed(4))-p_model1_mean(3),mrkr);
set(gca,'xticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4))));
ylabel('$\tilde{p}$ [Pa]');
ylim([-650 750]);
colororder(ax2,copper1(3));
text(0.05,0.08,'d)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];

ax3 = nexttile(7);
plt = plot(interval_t, -P_grad(:,[1,2])/sg,'LineWidth',wdth);
hold on;
plot(awgTime,dp1(probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2)/(rho*g),mrkr);
plot(awgTime,dp1(probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2)/(rho*g),mrkr);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$');
ylabel('$\Delta \tilde{p}$ [Pa/m]');
ylim([-0.3 0.45]);
colororder(ax3,copper2(2));
text(0.05,0.08,'g)','Units','normalized');
set(gca,'xticklabel',{[]})
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];

ax4 = nexttile(10);
plot(awgTime,dp1(0.01)/(rho*g));
ylabel('$\frac{d}{d \hat{z}} (\gamma \tilde{p})$ [-]');
xlim(plot_int);
% xlabel('Time [s]')
text(0.05,0.08,'j)','Units','normalized');
ylim([-3 1]);

linkaxes([ax1 ax2 ax3 ax4],'x');
xlim(plot_int);
pause(1)

%section 1
ax1 = nexttile(2);
plot(awgTime,awg2_s,'k');
title("Section 2");
set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
set(gca,'yticklabel',{[]})
ylim([0 0.45]);
text(0.05,0.08,'b)','Units','normalized');

ax2 = nexttile(5);
plt = plot(interval_t,P_fluct(:,[5:8]),'LineWidth',wdth);
hold on;
plot(awgTime,p2(probeDistToBed(5))-p_model2_mean(1),mrkr);
plot(awgTime,p2(probeDistToBed(6))-p_model2_mean(2),mrkr);
plot(awgTime,p2(probeDistToBed(7))-p_model2_mean(3),mrkr);
plot(awgTime,p2(probeDistToBed(8))-p_model2_mean(4),mrkr);
set(gca,'xticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7))),strcat('$\Delta z_b = $',num2str(probeDistToBed(8))));
% ylabel('$\tilde{p}$ [Pa]');
set(gca,'yticklabel',{[]})
ylim([-650 750]);
colororder(ax2,copper1(4));
text(0.05,0.08,'e)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];
plt(4).Color = [plt(4).Color trsp];

ax3 = nexttile(8);
plt = plot(interval_t, -P_grad(:,4:6)/sg,'LineWidth',wdth);
hold on;
plot(awgTime,dp2(probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2)/(rho*g),mrkr);
plot(awgTime,dp2(probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2)/(rho*g),mrkr);
plot(awgTime,dp2(probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2)/(rho*g),mrkr);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$', '$\nabla \tilde{p}_{3,4}$');
% ylabel('$\Delta \tilde{p}$ [Pa/m]');
set(gca,'yticklabel',{[]})
ylim([-0.3 0.45]);
colororder(ax3,copper2(3));
text(0.05,0.08,'h)','Units','normalized');
set(gca,'xticklabel',{[]})
% xlabel('$t$ [s]');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];

ax4 = nexttile(11);
plot(awgTime,dp2(0.01)/(rho*g));
% ylabel('$\frac{}{\partial \hat{z}} (\gamma p)$ [-]');
xlim(plot_int);
xlabel('$t$ [s]')
text(0.05,0.08,'k)','Units','normalized');
set(gca,'yticklabel',{[]})
ylim([-3 1]);

linkaxes([ax1 ax2 ax3 ax4],'x');
xlim(plot_int);
pause(1)

%section 1
ax1 = nexttile(3);
plot(awgTime,awg3_s,'k');
title("Section 3");
set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
set(gca,'yticklabel',{[]})
ylim([0 0.45]);
text(0.05,0.08,'c)','Units','normalized');

ax2 = nexttile(6);
plt = plot(interval_t,P_fluct(:,[9:10]),'LineWidth',wdth);
hold on;
plot(awgTime,p3(probeDistToBed(9))-p_model3_mean(1),mrkr);
plot(awgTime,p3(probeDistToBed(10))-p_model3_mean(2),mrkr);
set(gca,'xticklabel',{[]})
% ylabel('$\tilde{p}$ [Pa]');
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10))));
set(gca,'yticklabel',{[]})
set(gca,'yticklabel',{[]})
ylim([-650 750]);
colororder(ax2,copper1(2));
%colororder(ax2,[0 0.8 0.2; 0 0.2 0.05]);
 text(0.05,0.08,'f)','Units','normalized');
 plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];

ax3 = nexttile(9);
plt = plot(interval_t, -P_grad(:,7)/sg,'LineWidth',wdth);
hold on;
plot(awgTime,dp3(probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2)/(rho*g),mrkr);
% ylabel('$\nabla \tilde{p}$ [Pa/m]');
set(gca,'yticklabel',{[]})
linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
ylim([-0.3 0.45]);
text(0.05,0.08,'i)','Units','normalized');
set(gca,'xticklabel',{[]})
 colororder(ax3,copper2(1));
 plt.Color = [plt.Color trsp];

ax4 = nexttile(12);
plot(awgTime,dp3(0.01)/(rho*g));
% ylabel('$\frac{}{\partial \hat{z}} (\gamma p)$ [-]');
xlim(plot_int);
% xlabel('Time [s]')
text(0.05,0.08,'l)','Units','normalized');
linkaxes([ax1 ax2 ax3 ax4],'x');
set(gca,'yticklabel',{[]})
ylim([-3 1]);
pause(1)

%% Plot measurements only
plot_int = [1243,1293];
c = colororder;
pause(1)

wdth = 1;
mrkr = '-.';
trsp = 1;

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
sg = rho*g;

dp1_z = [probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2,...
    probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2];
dp2_z = [probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2,...
    probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2,...
    probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2];
dp3_z = probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2;

text_x1 = 1268;
text_y1 = interp1(interval_t,P_fluct(:,[1,2,4]),text_x1);

text_x2 = 1267;
text_y2 = interp1(interval_t,P_fluct(:,[5:8]),text_x2);

text_x3 = 1270;
text_y3 = interp1(interval_t,P_fluct(:,[9:10]),text_x3);

%section 1
figure;
tiledlayout(3,3,'tilespacing','compact','padding','compact');
ax1 = nexttile(3);
plot(awgTime,awg1_s,'k');
title("Location C");
set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
% ylabel('$\eta$ [m]');
ylim([0 0.45]);
text(0.15,0.9,'c)','Units','normalized');
alpha(0.5);

ax2 = nexttile(6);
plt = plot(interval_t,P_fluct(:,[1,2,4]),'LineWidth',wdth);
% hold on;
% plot(awgTime,p1(probeDistToBed(1))-p_model1_mean(1),mrkr);
% plot(awgTime,p1(probeDistToBed(2))-p_model1_mean(2),mrkr);
% plot(awgTime,p1(probeDistToBed(4))-p_model1_mean(3),mrkr);
set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4))));
% ylabel('$\tilde{p}$ [Pa]');
ylim([-650 750]);
colororder(ax2,copper1(3));
text(0.15,0.9,'f)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];

text(text_x1,text_y1(1),"$\longleftarrow C_3$");
text(text_x1,text_y1(2),"$C_2\longrightarrow$",'horizontalalignment','right');
text(text_x1,text_y1(3),"$\longleftarrow C_1$");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax3 = nexttile(9);
plt = plot(interval_t, -P_grad(:,[1,2])/sg,'LineWidth',wdth);
% hold on;
% plot(awgTime,dp1(probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2)/(rho*g),mrkr);
% plot(awgTime,dp1(probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2)/(rho*g),mrkr);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$');
% ylabel('$\Delta \tilde{p}$ [Pa/m]');
ylim([-0.3 0.45]);
colororder(ax3,copper2(2));
text(0.15,0.9,'i)','Units','normalized');
% set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
legend([plt(2),plt(1)],'Shallow','Deep');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');
xlabel('$t$ [s]');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
ax1 = nexttile(2);
plot(awgTime,awg2_s,'k');
title("Location B");
set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
set(gca,'yticklabel',{[]})
ylim([0 0.45]);
text(0.15,0.9,'b)','Units','normalized');

ax2 = nexttile(5);
plt = plot(interval_t,P_fluct(:,[5:8]),'LineWidth',wdth);
% hold on;
% plot(awgTime,p2(probeDistToBed(5))-p_model2_mean(1),mrkr);
% plot(awgTime,p2(probeDistToBed(6))-p_model2_mean(2),mrkr);
% plot(awgTime,p2(probeDistToBed(7))-p_model2_mean(3),mrkr);
% plot(awgTime,p2(probeDistToBed(8))-p_model2_mean(4),mrkr);
set(gca,'xticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7))),strcat('$\Delta z_b = $',num2str(probeDistToBed(8))));
% ylabel('$\tilde{p}$ [Pa]');
set(gca,'yticklabel',{[]})
ylim([-650 750]);
colororder(ax2,copper1(4));
text(0.15,0.9,'e)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];
plt(4).Color = [plt(4).Color trsp];

text(text_x2,text_y2(1),"$B_4\longrightarrow$",'horizontalalignment','right');
text(text_x2,text_y2(2),"$\longleftarrow B_3$");
text(text_x2,text_y2(3),"$B_2\longrightarrow$",'horizontalalignment','right');
text(text_x2,text_y2(4),"$\longleftarrow B_1$");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax3 = nexttile(8);
plt = plot(interval_t, -P_grad(:,4:6)/sg,'LineWidth',wdth);
% hold on;
% plot(awgTime,dp2(probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2)/(rho*g),mrkr);
% plot(awgTime,dp2(probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2)/(rho*g),mrkr);
% plot(awgTime,dp2(probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2)/(rho*g),mrkr);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$', '$\nabla \tilde{p}_{3,4}$');
% ylabel('$\Delta \tilde{p}$ [Pa/m]');
set(gca,'yticklabel',{[]})
ylim([-0.3 0.45]);
colororder(ax3,copper2(3));
text(0.15,0.9,'h)','Units','normalized');
% set(gca,'xticklabel',{[]})
xlabel('$t$ [s]');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
ax1 = nexttile(1);
plot(awgTime,awg3_s,'k');
title("Location A");
set(gca,'xticklabel',{[]})
ylabel('$h$ [m]');
% set(gca,'yticklabel',{[]})
ylim([0 0.45]);
text(0.15,0.9,'a)','Units','normalized');

ax2 = nexttile(4);
plt = plot(interval_t,P_fluct(:,[9:10]),'LineWidth',wdth);
% hold on;
% plot(awgTime,p3(probeDistToBed(9))-p_model3_mean(1),mrkr);
% plot(awgTime,p3(probeDistToBed(10))-p_model3_mean(2),mrkr);
set(gca,'xticklabel',{[]})
ylabel('$\tilde{p}$ [Pa]');
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10))));
% set(gca,'yticklabel',{[]})
ylim([-650 750]);
colororder(ax2,copper1(2));
%colororder(ax2,[0 0.8 0.2; 0 0.2 0.05]);
text(0.15,0.9,'d)','Units','normalized');
 plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];

text(text_x3,text_y3(1),"$A_2\longrightarrow$",'horizontalalignment','right');
text(text_x3,text_y3(2),"$\longleftarrow A_1$");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

legend([plt(2),plt(1)], 'Shallow','Deep');

ax3 = nexttile(7);
plt = plot(interval_t, -P_grad(:,7)/sg,'LineWidth',wdth);
% hold on;
% plot(awgTime,dp3(probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2)/(rho*g),mrkr);
ylabel('$\partial_z \tilde{p}$ [Pa/m]');
% set(gca,'yticklabel',{[]})
linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
ylim([-0.3 0.45]);
text(0.15,0.9,'g)','Units','normalized');
% set(gca,'xticklabel',{[]})
 colororder(ax3,copper2(1));
 plt.Color = [plt.Color trsp];
 
 hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');
 xlabel('$t$ [s]');
 
 linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
pause(1)
%% Plot only pressure and gradient (exp + mod)
plot_int = [1243,1288];
c = colororder;
pause(1)

wdth = 1;
mrkr = '--';
trsp = 1;

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
sg = rho*g;

dp1_z = [probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2,...
    probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2];
dp2_z = [probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2,...
    probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2,...
    probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2];
dp3_z = probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2;

%section 1
figure;
tiledlayout(3,2,'tilespacing','compact','padding','compact');
% ax1 = nexttile(5);
% plot(awgTime,awg1_s,'k');
% title("Location C");
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
% % ylabel('$\eta$ [m]');
% ylim([0 0.45]);
% text(0.05,0.9,'c)','Units','normalized');
% alpha(0.5);

ax2 = nexttile(5);
plt = plot(interval_t,P_fluct(:,[1,2,4]),'LineWidth',wdth,'HandleVisibility','off');
hold on;
plot(awgTime,p1(probeDistToBed(1))-p_model1_mean(1),mrkr);
plot(awgTime,p1(probeDistToBed(2))-p_model1_mean(2),mrkr,'HandleVisibility','off');
plot(awgTime,p1(probeDistToBed(4))-p_model1_mean(3),mrkr);
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(1))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(2))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(4))));
% ylabel('$\tilde{p}$ [Pa]');
% ylim([-650 750]);
colororder(ax2,[copper1(3);copper1(3)]);
text(0.20,0.9,'e)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];
% legend('Deep','Shallow');
xlabel('$t$ [s]');
ylabel('$\tilde{p}$ [Pa]');

 hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax3 = nexttile(6);
plt = plot(interval_t, -P_grad(:,[1,2])/sg,'LineWidth',wdth,'HandleVisibility','off');
hold on;
plot(awgTime,dp1(probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2)/(rho*g),mrkr);
plot(awgTime,dp1(probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2)/(rho*g),mrkr);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$');
% ylabel('$\Delta \tilde{p}$ [Pa/m]');
% ylim([-0.3 0.25]);
colororder(ax3,[copper2(2);copper2(2)]);
text(0.05,0.9,'f)','Units','normalized');
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
xlabel('$t$ [s]');
ylabel('$\partial_z \tilde{p}$ [Pa/m]');

 hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

linkaxes([ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
% ax1 = nexttile(2);
% plot(awgTime,awg2_s,'k');
% title("Location B");
% set(gca,'xticklabel',{[]})
% % ylabel('$\eta$ [m]');
% set(gca,'yticklabel',{[]})
% ylim([0 0.45]);
% text(0.05,0.9,'b)','Units','normalized');

ax2 = nexttile(3);
plt = plot(interval_t,P_fluct(:,[5:8]),'LineWidth',wdth);
hold on;
plot(awgTime,p2(probeDistToBed(5))-p_model2_mean(1),mrkr);
plot(awgTime,p2(probeDistToBed(6))-p_model2_mean(2),mrkr);
plot(awgTime,p2(probeDistToBed(7))-p_model2_mean(3),mrkr);
plot(awgTime,p2(probeDistToBed(8))-p_model2_mean(4),mrkr);
set(gca,'xticklabel',{[]})
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(5))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(6))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(7))),strcat('$\Delta z_b = $',num2str(probeDistToBed(8))));
ylabel('$\tilde{p}$ [Pa]');
% set(gca,'yticklabel',{[]})
% ylim([-650 750]);
colororder(ax2,[copper1(4);copper1(4)]);
text(0.20,0.9,'c)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];
plt(4).Color = [plt(4).Color trsp];

 hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax3 = nexttile(4);
plt = plot(interval_t, -P_grad(:,4:6)/sg,'LineWidth',wdth);
hold on;
plot(awgTime,dp2(probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2)/(rho*g),mrkr);
plot(awgTime,dp2(probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2)/(rho*g),mrkr);
plot(awgTime,dp2(probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2)/(rho*g),mrkr);
% legend('$\nabla \tilde{p}_{1,2}$', '$\nabla \tilde{p}_{2,3}$', '$\nabla \tilde{p}_{3,4}$');
ylabel('$\partial_z \tilde{p}$ [Pa/m]');
% set(gca,'yticklabel',{[]})
% ylim([-0.3 0.25]);
colororder(ax3,[copper2(3);copper2(3)]);
text(0.05,0.9,'d)','Units','normalized');
set(gca,'xticklabel',{[]})
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];

 hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

linkaxes([ax2 ax3],'x');
xlim(plot_int);
pause(1)

%section 1
% ax1 = nexttile(1);
% plot(awgTime,awg3_s,'k');
% title("Location A");
% set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
% % set(gca,'yticklabel',{[]})
% ylim([0 0.45]);
% text(0.05,0.9,'a)','Units','normalized');

ax2 = nexttile(1);
plt = plot(interval_t,P_fluct(:,[9:10]),'LineWidth',wdth);
hold on;
plot(awgTime,p3(probeDistToBed(9))-p_model3_mean(1),mrkr);
plot(awgTime,p3(probeDistToBed(10))-p_model3_mean(2),mrkr);
set(gca,'xticklabel',{[]})
% ylabel('$\tilde{p}$ [Pa]');
% legend(strcat('$\Delta z_b = $ ',num2str(probeDistToBed(9))),strcat('$\Delta z_b = $ ',num2str(probeDistToBed(10))));
% set(gca,'yticklabel',{[]})
% ylim([-650 750]);
colororder(ax2,[copper1(2);copper1(2)]);
%colororder(ax2,[0 0.8 0.2; 0 0.2 0.05]);
text(0.20,0.9,'a)','Units','normalized');
 plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
ylabel('$\tilde{p}$ [Pa]');

% legend('Measured','Modelled');

 hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

% legend('Deep','Shallow');

ax3 = nexttile(2);
plt = plot(interval_t, -P_grad(:,7)/sg,'LineWidth',wdth);
hold on;
plot(awgTime,dp3(probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2)/(rho*g),mrkr);
% ylabel('$\nabla \tilde{p}$ [Pa/m]');
% set(gca,'yticklabel',{[]})
linkaxes([ax1 ax2 ax3],'x');
xlim(plot_int);
% ylim([-0.3 0.25]);
text(0.05,0.9,'b)','Units','normalized');
set(gca,'xticklabel',{[]})
 colororder(ax3,[copper2(1);copper2(1)]);
 plt.Color = [plt.Color trsp];
 ylabel('$\partial_z \tilde{p}$ [Pa/m]');
 
legend('Measured','Modelled');
 
  hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');
 
 
 linkaxes([ax2 ax3],'x');
xlim(plot_int);
pause(1)
%%
plot_int = [1243,1293];
c = colororder;
pause(1)

wdth = 1;
mrkr = '-.';
trsp = 1;

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

init_eta = 2.47 + interp1(profile_x,profile_z,xAWG(awg_idx));
sg = rho*g;

dp1_z = [probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2,...
    probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2];
dp2_z = [probeDistToBed(5)-(probeDistToBed(5)-probeDistToBed(6))/2,...
    probeDistToBed(6)-(probeDistToBed(6)-probeDistToBed(7))/2,...
    probeDistToBed(7)-(probeDistToBed(7)-probeDistToBed(8))/2];
dp3_z = probeDistToBed(9)-(probeDistToBed(9)-probeDistToBed(10))/2;


%section 1
figure;
tiledlayout(2,1,'tilespacing','compact','padding','compact');
% ax1 = nexttile(5);
% plot(awgTime,awg1_s,'k');
% title("Location C");
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
% % ylabel('$\eta$ [m]');
% ylim([0 0.45]);
% text(0.05,0.9,'c)','Units','normalized');
% alpha(0.5);

ax2 = nexttile(1);
plt = plot(interval_t,P_fluct(:,[1,2,4]),'LineWidth',wdth);
hold on;
plot(awgTime,p1(probeDistToBed(1))-p_model1_mean(1),mrkr);
plot(awgTime,p1(probeDistToBed(2))-p_model1_mean(2),mrkr);
plot(awgTime,p1(probeDistToBed(4))-p_model1_mean(3),mrkr);
set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
ylabel('$\tilde{p}$ [Pa]');
ylim([-650 750]);
colororder(ax2,copper1(3));
text(0.05,0.9,'a)','Units','normalized');
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
plt(3).Color = [plt(3).Color trsp];
legend('Deep','Middle','Shallow');

ax3 = nexttile(2);
plt = plot(interval_t, -P_grad(:,[1,2])/sg,'LineWidth',wdth);
hold on;
plot(awgTime,dp1(probeDistToBed(1)-(probeDistToBed(1)-probeDistToBed(2))/2)/(rho*g),mrkr);
plot(awgTime,dp1(probeDistToBed(2)-(probeDistToBed(2)-probeDistToBed(4))/2)/(rho*g),mrkr);
ylabel('$\Delta \tilde{p}$ [Pa/m]');
ylim([-0.3 0.45]);
colororder(ax3,copper2(2));
text(0.05,0.9,'b)','Units','normalized');
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
plt(1).Color = [plt(1).Color trsp];
plt(2).Color = [plt(2).Color trsp];
legend('Deep','Shallow');

linkaxes([ax2 ax3],'x');
xlim(plot_int);
pause(1)

pause(1)
%% ADV part
plot_int2 = [1282,1296];
plot_int2 = [1255,1300];
% plot_int2 = plot_int;

adv_idx = [6, 5, 3];

dtU = time_wp(1);
% dtU = 0;
[~,intADV_a] = min(abs(time_adv - interval(1)-dtU));
[~,intADV_b] = min(abs(time_adv - interval(2)-dtU));
intervalIdxADV = [intADV_a, intADV_b];
intervalADV_t = time_adv(intADV_a:intADV_b);

adv1 = adv_out.x([intADV_a:intADV_b],adv_idx(1));
adv2 = adv_out.x([intADV_a:intADV_b],adv_idx(2));
adv3 = adv_out.x([intADV_a:intADV_b],adv_idx(3));

adv1_s = smoothdata(adv1,'gaussian',10);
adv2_s = smoothdata(adv2,'gaussian',10);
adv3_s = smoothdata(adv3,'gaussian',10);

wetLimit = 50;

wet1 = [smoothdata(abs(diff(adv1)),'movmedian',30)<wetLimit;0];
wet2 = [smoothdata(abs(diff(adv2)),'movmedian',30)<wetLimit;0];
wet3 = [smoothdata(abs(diff(adv3)),'movmedian',30)<wetLimit;0];

intervalADV_t = intervalADV_t - dtU;
% u1=adv1;
% u2=adv2;
% u3=adv3;

u1 = adv1_s.*wet1/100;
u1(u1==0)=nan;

u2 = adv2_s.*wet2/100;
u2(u2==0)=nan;

u3 = adv3_s.*wet3/100;
u3(u3==0)=nan;

p1_interp = interp1(awgTime,dp1(0.01)/(rho*g),intervalADV_t);
p2_interp = interp1(awgTime,dp2(0.01)/(rho*g),intervalADV_t);
p3_interp = interp1(awgTime,dp3(0.01)/(rho*g),intervalADV_t);

s = 2650/1000; %Specific gravity
n = 0.4; %porosity
% s = 2000/1000;

theta1 = u1.*u1.*sign(u1)./(s-1);
theta2 = u2.*u2.*sign(u2)./(s-1);
theta3 = u3.*u3.*sign(u3)./(s-1);

thetap1 = u1.*u1.*sign(u1)./((s-1)-p1_interp');
thetap2 = u2.*u2.*sign(u2)./((s-1)-p2_interp');
thetap3 = u3.*u3.*sign(u3)./((s-1)-p3_interp');

theta1_porous = u1.*u1.*sign(u1)./(s-1);
theta2_porous = u2.*u2.*sign(u2)./(s-1);
theta3_porous = u3.*u3.*sign(u3)./(s-1);

thetap1_porous = u1.*u1.*sign(u1)*(1-n)./((s-1)*(1-n)-p1_interp');
thetap2_porous = u2.*u2.*sign(u2)*(1-n)./((s-1)*(1-n)-p2_interp');
thetap3_porous = u3.*u3.*sign(u3)*(1-n)./((s-1)*(1-n)-p3_interp');

figure;
tiledlayout(2,3,'tilespacing','compact','padding','compact');

% ax11 = nexttile();
% plot(awgTime,awg3_s,'k');
% title("Section A");
% set(gca,'xticklabel',{[]})
% ylabel('$\eta$ [m]');
% ylim([0 0.45]);
% text(0.05,0.9,'a)','Units','normalized');
% xlim([plot_int2]);
% alpha(0.5);
% 
% ax21 = nexttile();
% plot(awgTime,awg2_s,'k');
% title("Section B");
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
% ylim([0 0.45]);
% text(0.05,0.9,'b)','Units','normalized');
% xlim([plot_int2]);
% alpha(0.5);
% 
% ax31 = nexttile();
% plot(awgTime,awg1_s,'k');
% title("Section C");
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
% ylim([0 0.45]);
% text(0.05,0.9,'c)','Units','normalized');
% xlim([plot_int2]);
% alpha(0.5);

ax12 = nexttile();
plot(intervalADV_t,theta3);
hold on;
plot(intervalADV_t,thetap3);
set(gca,'xticklabel',{[]})
ylabel('Transport mobility [m$^2$/s$^2$]');
text(0.05,0.9,'a)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location A");
legend('normal','pressure dependent');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax22 = nexttile();
plot(intervalADV_t,theta2);
hold on;
plot(intervalADV_t,thetap2);
set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
text(0.05,0.9,'b)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location B");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax32 = nexttile();
plot(intervalADV_t,theta1);
hold on;
plot(intervalADV_t,thetap1);
set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
text(0.05,0.9,'c)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location C");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax13 = nexttile();
plot(awgTime,dp3(0.01)/(rho*g),'k');
ylabel('$\partial (\tilde{p}/\gamma)/\partial \hat{z}$ [-]');
xlim([plot_int2]);
ylim([-2,1]);
text(0.05,0.9,'d)','Units','normalized');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax23 = nexttile();
plot(awgTime,dp2(0.01)/(rho*g),'k');
set(gca,'yticklabel',{[]})
xlim([plot_int2]);
ylim([-2,1]);
text(0.05,0.9,'e)','Units','normalized');
xlabel('$t$ [s]');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax33 = nexttile();
plot(awgTime,dp1(0.01)/(rho*g),'k');
set(gca,'yticklabel',{[]})
xlim([plot_int2]);
ylim([-2,1]);
text(0.05,0.9,'f)','Units','normalized');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

% linkaxes([ax11,ax12,ax13],'x');
% linkaxes([ax21,ax22,ax23],'x');
% linkaxes([ax31,ax32,ax33],'x');

figure;
tiledlayout(2,3,'tilespacing','compact','padding','compact');

ax12 = nexttile();
plot(intervalADV_t,theta3_porous);
hold on;
plot(intervalADV_t,thetap3_porous);
set(gca,'xticklabel',{[]})
ylabel('Transport mobility [m$^2$/s$^2$]');
text(0.05,0.9,'a)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location A");
legend('normal','pressure dependent');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax22 = nexttile();
plot(intervalADV_t,theta2_porous);
hold on;
plot(intervalADV_t,thetap2_porous);
set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
text(0.05,0.9,'b)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location B");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax32 = nexttile();
plot(intervalADV_t,theta1_porous);
hold on;
plot(intervalADV_t,thetap1_porous);
set(gca,'xticklabel',{[]})
set(gca,'yticklabel',{[]})
text(0.05,0.9,'c)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location C");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax13 = nexttile();
plot(awgTime,dp3(0.01)/(rho*g),'k');
ylabel('$\partial (\tilde{p}/\gamma)/\partial \hat{z}$ [-]');
xlim([plot_int2]);
ylim([-2,1]);
text(0.05,0.9,'d)','Units','normalized');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax23 = nexttile();
plot(awgTime,dp2(0.01)/(rho*g),'k');
set(gca,'yticklabel',{[]})
xlim([plot_int2]);
ylim([-2,1]);
text(0.05,0.9,'e)','Units','normalized');
xlabel('$t$ [s]');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax33 = nexttile();
plot(awgTime,dp1(0.01)/(rho*g),'k');
set(gca,'yticklabel',{[]})
xlim([plot_int2]);
ylim([-2,1]);
text(0.05,0.9,'f)','Units','normalized');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');


%% Plotting both in one figure;
figure;
tiledlayout(1,3,'tilespacing','compact','padding','compact');

ax12 = nexttile();
plot(intervalADV_t,theta3_porous);
hold on;
plot(intervalADV_t,thetap3_porous);
plot(intervalADV_t,thetap3);
% set(gca,'xticklabel',{[]})
ylabel('Transport mobility [m$^2$/s$^2$]');
text(0.05,0.9,'a)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location A");
legend('normal','pressure dependent with porosity','pressure dependent without porosity');

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax22 = nexttile();
plot(intervalADV_t,theta2_porous);
hold on;
plot(intervalADV_t,thetap2_porous);
plot(intervalADV_t,thetap2);
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
text(0.05,0.9,'b)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location B");
xlabel("t [s]");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

ax32 = nexttile();
plot(intervalADV_t,theta1_porous);
hold on;
plot(intervalADV_t,thetap1_porous);
plot(intervalADV_t,thetap1);
% set(gca,'xticklabel',{[]})
% set(gca,'yticklabel',{[]})
text(0.05,0.9,'c)','Units','normalized');
xlim([plot_int2]);
ylim([-1.5,1.5]);
title("Location C");

hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

% ax13 = nexttile();
% plot(awgTime,dp3(0.01)/(rho*g),'k');
% ylabel('$\partial (\tilde{p}/\gamma)/\partial \hat{z}$ [-]');
% xlim([plot_int2]);
% ylim([-2,1]);
% text(0.05,0.9,'d)','Units','normalized');
% 
% hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');
% 
% ax23 = nexttile();
% plot(awgTime,dp2(0.01)/(rho*g),'k');
% set(gca,'yticklabel',{[]})
% xlim([plot_int2]);
% ylim([-2,1]);
% text(0.05,0.9,'e)','Units','normalized');
% xlabel('$t$ [s]');
% 
% hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');
% 
% ax33 = nexttile();
% plot(awgTime,dp1(0.01)/(rho*g),'k');
% set(gca,'yticklabel',{[]})
% xlim([plot_int2]);
% ylim([-2,1]);
% text(0.05,0.9,'f)','Units','normalized');

% hold on; plt1 = plot([0,10000],[0,0],'k','HandleVisibility','off');

%%

function colorMat = copper2(m)
    colorMat = max(0.2,min(1,gray(m)*diag([0.400 0.712 0.475])));
end

function colorMat = copper1(m)
    colorMat = max(0.2,min(1,gray(m)*diag([0.2812 0.5975 2.00 ])));
end

function colorMat = copper3(m)
    beginColor = [1,0.5,0];
    endColor = [0.5,0.2,0];

    colorMat = interp1([0,1],[endColor;beginColor],linspace(0,1,m));

end

function colorMat = copper4(m)
    beginColor = [1,0.5,0.5];
    endColor = [0.5,0,0.2];

    colorMat = interp1([0,1],[endColor;beginColor],linspace(0,1,m));

end