% Analyze surface elevations for case 1

run_nr = 79;
% run_nr = 91;
calibration = 1; % 1 to use probe calibration for stb1, 2 for stb2;
flagSaveFigures = 0;
flagDoModelCalibration = 0; %Flag to specify if the user wants to use the
% calibration script for determining calibration constants. If 0, please
% specify calibration constants a1, a2, a3.

load('xPPT.mat');
load('zPPT_abs.mat');
load('zPPT_rel.mat');
load(strcat('calCoeffs',num2str(calibration),'.mat')); %Coefficients from the probe calibration
% load(strcat('AWG',num2str(run_nr),'Smooth.mat')); %Smoothed awg signals per section
load(strcat('StB_run',num2str(run_nr),'.mat'));
if run_nr > 9
    load(strcat('EC1StB_0',num2str(run_nr-14),'PPT.mat'));
elseif run_nr < 10
    load(strcat('StB2ppt_00',num2str(run_nr),'.mat'));
end
%Note that the ppt variable gives results from ppts used as wave-gauges.
load('prof_data_corrected');
profile_z = p(run_nr - 18).z;
profile_x = p(run_nr -18).x;
disp(head{run_nr - 18});

probeDistToBed = getProbeDistanceToBedWithScour(run_nr,xPPT,zPPT_abs,p);

rho = 1000;
g = 9.81;

[ppt_t,ppt_p] = getPPTData_1(PPT_data);
P = getPressureFromSignal(ppt_p,A,B);

set(groot,'defaultAxesXGrid','on')
set(groot,'defaultAxesYGrid','on')

if (flagDoModelCalibration)
   doCalibration;
   a1 = bestRMSE_a(1);
   a2 = bestRMSE_a(2);
   a3 = bestRMSE_a(3);
   disp('Model calibration coefficients: ');
   disp([a1,a2,a3]);
end
%% Apply pressure model

% h_av1 = 0.16;
% h_av2 = 0.16;
% h_av3 = 0.16;
interval  = [1000 1800];
plot_int = [1243,1293];

% frequency=[0:ceil(nbrSamples/2)-1,-floor(nbrSamples/2):-1]'/sampleInterval/nbrSamples;
% TODO: From here the awg signal needs to be aligned with the ppt signal.
awg_f = 40;
Tawg_length = interval(2)-interval(1);

awg_L = length(awg1_s);
spectrumP0_f = [0:ceil(awg_L/2)-1 , -floor(awg_L/2):-1]'*(awg_f/awg_L);
p0_1_spectral = fft(p0_1);
p0_2_spectral = fft(p0_2);
p0_3_spectral = fft(p0_3);

ppt_f = 100;
T_length = interval(2)-interval(1);
ppt_L = length(P_fluct);
spectrum_f = (1:ppt_L)*(ppt_f/ppt_L);
P_spectral = fft(P_fluct);

omega = spectrumP0_f*2*pi;
% omega(omega<0) = -1*omega(omega<0);
k1 = omega/sqrt(g*h_av1);
k2 = omega/sqrt(g*h_av2);
k3 = omega/sqrt(g*h_av3);

if(~flagDoModelCalibration)
    disp("WARNING: Using default model calibration coefficients");
    a1 = 39.6
    a2 = 37.7
    a3 = 25.9
end
%% Analysis of wave gauges
% For section 1
% x ppt is 78.23
% wave gauges 20 (x = 78.01) and 21 (x = 78.74)

awg_idx = [20,19,14];

Fs = 40; % Hz, frequency of RWG, AWG and PPT
% Cut-off frequency for AWG (instrumentation noise)
Fc_hf = 8; %(highfreq) freq of short waves higher frequency limit
[B,A] = butter(4,Fc_hf/(Fs/2));

%Get the time lags
[pptlag1,pptlag2,pptlag3] = getPPTTimeLags(time_wp,AWG);

%Load the wave gauges used for the pressure
[awgTime,awg1_s,awg2_s,awg3_s] = getAWGInInterval(AWG,time_wp,awg_idx,interval);

h_av1 = mean(awg1_s);
h_av2 = mean(awg2_s);
h_av3 = mean(awg3_s);

p0_1 = rho*g*awg1_s;
p0_2 = rho*g*awg2_s;
p0_3 = rho*g*awg3_s;

%%
% T_tryShort = 3.56;
T_tryShort = 3.883; 
T_tryLong = 21;
omegaShort = 2*pi/T_tryShort;
omegaLong = 2*pi/T_tryLong;
aMat = [39.6,37.7,25.9;43.0,38.9,29.9; 49.8, 37.9, 27.5; 48.6, 40.9, 28.3];
aMean = mean(aMat);
% a1=aMean(1);
% a2=aMean(2);
% a3=aMean(3);

a1 = 39.6;
a2 = 37.7;
a3 = 25.9;

% omega(omega<0) = -1*omega(omega<0);
k1 = omegaShort/sqrt(g*h_av1);
k2 = omegaShort/sqrt(g*h_av2);
k3 = omegaShort/sqrt(g*h_av3);

kp1 = k1.*sqrt(1+(1i*omegaShort*a1)./(k1.*k1));
kp2 = k2.*sqrt(1+(1i*omegaShort*a2)./(k2.*k2));
kp3 = k3.*sqrt(1+(1i*omegaShort*a3)./(k3.*k3));

k1Long = omegaLong/sqrt(g*h_av1);
k2Long = omegaLong/sqrt(g*h_av2);
k3Long = omegaLong/sqrt(g*h_av3);

kp1Long = k1Long.*sqrt(1+(1i*omegaLong*a1)./(k1Long.*k1Long));
kp2Long = k2Long.*sqrt(1+(1i*omegaLong*a2)./(k2Long.*k2Long));
kp3Long = k3Long.*sqrt(1+(1i*omegaLong*a3)./(k3Long.*k3Long));

z=linspace(0,5,1000);
pAbs1 = abs(exp(-kp1.*z));
pAngle1 = angle(exp(-kp1.*z));
pAbs2 = abs(exp(-kp2.*z));
pAngle2 = angle(exp(-kp2.*z));
pAbs3 = abs(exp(-kp3.*z));
pAngle3 = angle(exp(-kp3.*z));

pGAbs1 = abs(-kp1.*exp(-kp1.*z));
pGAngle1 = angle(-kp1.*exp(-kp1.*z));
pGAbs2 = abs(-kp2.*exp(-kp2.*z));
pGAngle2 = angle(-kp2.*exp(-kp2.*z));
pGAbs3 = abs(-kp3.*exp(-kp3.*z));
pGAngle3 = angle(-kp3.*exp(-kp3.*z));

pAbs1Long = abs(exp(-kp1Long.*z));
pAngle1Long = angle(exp(-kp1Long.*z));
pAbs2Long = abs(exp(-kp2Long.*z));
pAngle2Long = angle(exp(-kp2Long.*z));
pAbs3Long = abs(exp(-kp3Long.*z));
pAngle3Long = angle(exp(-kp3Long.*z));

pGAbs1Long = abs(-kp1Long.*exp(-kp1Long.*z));
pGAngle1Long = angle(-kp1Long.*exp(-kp1Long.*z));
pGAbs2Long = abs(-kp2Long.*exp(-kp2Long.*z));
pGAngle2Long = angle(-kp2Long.*exp(-kp2Long.*z));
pGAbs3Long = abs(-kp3Long.*exp(-kp3Long.*z));
pGAngle3Long = angle(-kp3Long.*exp(-kp3Long.*z));

%These values are taken manually from peaks in the fourier spectrum
PC_fs = [92.9926,14.5913,7.97272,2.98455];
% PC_fs = [36.9521,7.88788,4.18913,1.52703];
% PC_fs = [58.4818,11.4336,5.56336,2.92767];
PC_fs_rel = [PC_fs(2)/PC_fs(1),PC_fs(3)/PC_fs(1),PC_fs(4)/PC_fs(1)];
ZC = [0.3, 0.4, 0.65];

ZB = [0.35, 0.39, 0.435, 0.52];
PB_fs = [115.087,16.0946,12.4777,10.9294,5.40036];
% PB_fs = [37.1159,4.64816,3.22439,2.99158,1.42399];
% PB_fs = [64.6486,9.9682,7.30491,6.28537,1.42399];
PB_fs_rel = [PB_fs(2)/PB_fs(1), PB_fs(3)/PB_fs(1), PB_fs(4)/PB_fs(1), PB_fs(5)/PB_fs(1),];

ZA = [0.4,0.5];
PA_fs = [171.574,27.0654, 13.1071];
% PA_fs = [19.3454, 4.20176, 1.79157];
% PA_fs = [83.4853,14.1637, 6.21535];
PA_fs_rel = [PA_fs(2)/PA_fs(1),PA_fs(3)/PA_fs(1)];

PA_fl = [827.66, 450.643, 352.651];
PB_fl = [633.644, 344.394, 314.64, 295.884, 233.329];
PC_fl = [546.803, 326.075, 275.38, 201.671];

PA_fl_rel = [PA_fl(2)/PA_fl(1),PA_fl(3)/PA_fl(1)];
PB_fl_rel = [PB_fl(2)/PB_fl(1), PB_fl(3)/PB_fl(1), PB_fl(4)/PB_fl(1), PB_fl(5)/PB_fl(1),];
PC_fl_rel = [PC_fl(2)/PC_fl(1),PC_fl(3)/PC_fl(1),PC_fl(4)/PC_fl(1)];



figure;
tiledlayout(2,2,'tilespacing','compact','padding','compact');
ax1 = nexttile;
plot(pAbs1,z);
hold on;
plot(pAbs2,z);
plot(pAbs3,z);

set(gca,'ColorOrderIndex',1)
plot(pAbs1Long,z,'--');
hold on;
plot(pAbs2Long,z,'--');
plot(pAbs3Long,z,'--');
text(0.05,0.92,'a)','Units','normalized');

ylim([0,0.7]);
set(gca, 'YDir','reverse')
ylabel('$\hat{z}$ [m]');
title('$|p^*_j(\hat{z})/p^*_j(0)|$');
xlabel('Amplitude [-]');

set(gca,'ColorOrderIndex',1)
plot(PC_fs_rel,ZC,'*');
plot(PB_fs_rel,ZB,'*');
plot(PA_fs_rel,ZA,'*');
set(gca,'ColorOrderIndex',1)
plot(PC_fl_rel,ZC,'x');
plot(PB_fl_rel,ZB,'x');
plot(PA_fl_rel,ZA,'x');

ax2 = nexttile;
plot(unwrap(pAngle1),z);
hold on;
plot(unwrap(pAngle2),z);
plot(unwrap(pAngle3),z);

set(gca,'ColorOrderIndex',1)
plot(unwrap(pAngle1Long),z,'--');
hold on;
plot(unwrap(pAngle2Long),z,'--');
plot(unwrap(pAngle3Long),z,'--');
ylim([0,0.7]);
xlim([-pi,pi/4]);
xticks(-pi:pi/4:pi);
xticklabels(["-$\pi$", "-3/4$\pi$","-1/2$\pi$","-1/4$\pi$","0","1/4$\pi$"]);
set(gca, 'YDir','reverse')
text(0.05,0.92,'b)','Units','normalized');
title('$\varphi(p^*_j(\hat{z})/p^*_j(0))$');
xlabel('Phase [Rad.]');

ax3 = nexttile;
plot(pGAbs1,z);
hold on;
plot(pGAbs2,z);
plot(pGAbs3,z);

set(gca,'ColorOrderIndex',1)
plot(pGAbs1Long,z,'--');
hold on;
plot(pGAbs2Long,z,'--');
plot(pGAbs3Long,z,'--');

ylim([0,0.7]);
set(gca, 'YDir','reverse')
xlabel('Amplitude [m$^{-1}$]');
ylabel('$\hat{z}$ [m]');
text(0.05,0.92,'c)','Units','normalized');
title('$|\frac{\partial p_j^*}{\partial \hat{z}}(\hat{z})/p_j^*(0)|$');

ax4 = nexttile;
plot(unwrap(pGAngle1),z);
hold on;
plot(unwrap(pGAngle2),z);
plot(unwrap(pGAngle3),z);

set(gca,'ColorOrderIndex',1)
plot(unwrap(pGAngle1Long),z,'--');
hold on;
plot(unwrap(pGAngle2Long),z,'--');
plot(unwrap(pGAngle3Long),z,'--');
ylim([0,0.7]);
xlim([-2*pi,-2/3*pi]);
xticks([-2*pi:1/3*pi:-2/3*pi]);
xticklabels(["-2$\pi$","-5/3$\pi$","-4/3$\pi$","-$\pi$","-2/3$\pi$"]);

set(gca, 'YDir','reverse')
xlabel('Phase [Rad.]');
text(0.05,0.92,'d)','Units','normalized');
title('$\varphi(\frac{\partial p_j^*}{\partial \hat{z}}(\hat{z})/p_j^*(0))$');

legend('a = 39.6 s/m$^2$','a = 37.7 s/m$^2$','a = 25.9 s/m$^2$','location','NorthWest');
%%
